@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusApp.c#28 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/argus/ArgusApp.c#29 $
+ * $DateTime: 2015/06/29 16:17:25 $
+ * $Change: 3027 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -276,7 +276,8 @@ ArgusUpdateAppState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                                        }
                                     } else {
                                        if ((sport == ARGUS_UDT_PORT) || (dport == ARGUS_UDT_PORT)) {
-                                          if (ArgusParseUDTHeader (model, (struct udt_header *) model->ArgusThisUpHdr)) {
+                                          unsigned int status = 0;
+                                          if (ArgusParseUDTHeader (model, (struct udt_header *) model->ArgusThisUpHdr, &status)) {
                                              struct ArgusNetworkStruct *net = (struct ArgusNetworkStruct *) flowstr->dsrs[ARGUS_NETWORK_INDEX];
 
                                              if (net == NULL) {
@@ -293,6 +294,9 @@ ArgusUpdateAppState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                                                 struct ArgusUDTObject *udtObject = (struct ArgusUDTObject *)(&net->hdr + 1);
                                                 bcopy (ArgusThisUdtHshake, &udtObject->hshake, sizeof(*ArgusThisUdtHshake));
                                              }
+
+                                             if (status != 0) 
+                                                net->net_union.udt.status |= status;
                                           }
                                        }
                                     }
