@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Arp Procession
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusArp.c#27 $
- * $DateTime: 2012/01/03 19:15:19 $
- * $Change: 2274 $
+ * $Id: //depot/argus/argus/argus/ArgusArp.c#32 $
+ * $DateTime: 2015/04/17 08:10:46 $
+ * $Change: 3011 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -158,8 +158,8 @@ ArgusCreateArpFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
                arp_spa = ntohl(arp_spa);
                arp_tpa = ntohl(arp_tpa);
 #endif
-               if (arp_spa > arp_tpa)
-                  model->state |= ARGUS_DIRECTION;
+//             if (arp_spa > arp_tpa)
+//                model->state |= ARGUS_DIRECTION;
 
                retn->arp_flow.hrd = HRD(ahdr);
                retn->arp_flow.pro = PRO(ahdr);
@@ -187,7 +187,7 @@ ArgusCreateArpFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
                arp_spa = ntohl(arp_spa);
                arp_tpa = ntohl(arp_tpa);
 #endif
-               if (arp_spa > arp_tpa)
+//             if (arp_spa > arp_tpa)
                   model->state |= ARGUS_DIRECTION;
 
                retn->arp_flow.hrd     = HRD(ahdr);
@@ -245,7 +245,7 @@ ArgusCreateArpFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
    }
 
 #ifdef ARGUSDEBUG
-   ArgusDebug (8, "ArgusCreateArpFlow (0x%x) returning %d\n", ep, retn);
+   ArgusDebug (8, "ArgusCreateArpFlow (%p) returning %p\n", ep, retn);
 #endif
 
    return (retn);
