@@ -416,7 +416,7 @@ struct ArgusRecord {
 
       trans->hdr.type              = ARGUS_TRANSPORT_DSR;
       trans->hdr.subtype           = ARGUS_SRCID | ARGUS_SEQ;
-      trans->hdr.argus_dsrvl8.qual = events->ArgusSrc->type;;
+      trans->hdr.argus_dsrvl8.qual = events->ArgusSrc->type;
       trans->hdr.argus_dsrvl8.len  = 3;
       tlen += trans->hdr.argus_dsrvl8.len;
 
