@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Fragment processing
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusFrag.c#26 $
- * $DateTime: 2012/01/03 19:15:19 $
- * $Change: 2274 $
+ * $Id: //depot/argus/argus/argus/ArgusFrag.c#30 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -327,7 +327,7 @@ ArgusUpdateFRAGState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *
             struct ip6_frag *tfrag = model->ArgusThisIpv6Frag;
             struct ip6_hdr  *iphdr = (struct ip6_hdr *)model->ArgusThisIpHdr;
             if (!(tfrag->ip6f_offlg & IP6F_MORE_FRAG))
-               frag->totlen = (ntohs(tfrag->ip6f_offlg & IP6F_OFF_MASK) + (iphdr->ip6_plen - 8));
+               frag->totlen = (ntohs(tfrag->ip6f_offlg & IP6F_OFF_MASK) + (ntohs(iphdr->ip6_plen) - 8));
             break;
          }
       }
