@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusIcmp.c#22 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/argus/ArgusIcmp.c#23 $
+ * $DateTime: 2015/08/05 22:33:18 $
+ * $Change: 3042 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,7 +46,7 @@ ArgusCreateICMPv6Flow (struct ArgusModelerStruct *model, struct icmp6_hdr *icmp)
    struct ArgusSystemFlow *retn = NULL;
 
    if (STRUCTCAPTURED(model, *icmp)) {
-      struct ArgusICMPv6Flow *icmpv6Flow = &model->ArgusThisFlow->icmp6_flow;
+      struct ArgusICMPv6Flow *icmpv6Flow = &model->ArgusThisFlow->icmpv6_flow;
 
       icmpv6Flow->type = icmp->icmp6_type;
 
