@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusModeler.h#59 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/argus/ArgusModeler.h#60 $
+ * $DateTime: 2015/06/29 16:17:25 $
+ * $Change: 3027 $
  */
 
 
@@ -387,6 +387,14 @@ struct ArgusFlowStruct {
    struct ArgusCanonRecord canon;
 };
 
+struct erspan_ii_header {
+   u_int16_t ver_vlan;
+   u_int16_t cos_ent_session;
+   u_int32_t resvert_index;
+};
+
+#define ERSPAN_VER(x)          ( ntohs(((struct erspan_ii_header *) x)->ver_vlan) >> 12 )
+
 
 #if defined(ArgusModeler)
 
@@ -478,7 +486,7 @@ struct timeval *getArgusListenInterval(struct ArgusModelerStruct *);
 
 
 extern struct udt_control_handshake *ArgusThisUdtHshake;
-extern int ArgusParseUDTHeader (struct ArgusModelerStruct *, struct udt_header *);
+extern int ArgusParseUDTHeader (struct ArgusModelerStruct *, struct udt_header *, unsigned int *);
 
 int getArgusdflag(struct ArgusModelerStruct *);
 void setArgusdflag(struct ArgusModelerStruct *, int);
@@ -660,7 +668,7 @@ extern struct timeval ArgusListenInterval;
 extern struct timeval *getArgusListenInterval(void);
 
 extern struct udt_control_handshake *ArgusThisUdtHshake;
-extern int ArgusParseUDTHeader (struct ArgusModelerStruct *, struct udt_header *);
+extern int ArgusParseUDTHeader (struct ArgusModelerStruct *, struct udt_header *, unsigned int *);
 
 extern int getArgusGenerateTime(struct ArgusModelerStruct *);
 extern void setArgusGenerateTime(struct ArgusModelerStruct *, int);
