@@ -1266,9 +1266,10 @@ ArgusParseCiscoRecordV9Data (struct ArgusParserStruct *parser, struct ArgusModel
                            break;
                         }
                         case k_CiscoV9IpV6IcmpType: {
-                           flow->canon.icmp.icmp_type = value.val8[0];
-                           flow->dsrindex |= 1 << ARGUS_ICMP_INDEX;
-                           flow->dsrs[ARGUS_ICMP_INDEX] = &flow->canon.icmp.hdr;
+                           struct ArgusICMPv6Flow *icmpv6Flow = &flow->canon.flow.icmpv6_flow;
+                           icmpv6Flow->type = value.val8[0];
+                           flow->dsrindex |= 1 << ARGUS_FLOW_INDEX;
+                           flow->dsrs[ARGUS_FLOW_INDEX] = &flow->canon.flow.hdr;
                            break;
                         }
                         case k_CiscoV9IpV6MulIgmpType: {
@@ -1473,14 +1474,14 @@ ArgusParseCiscoRecordV9Data (struct ArgusParserStruct *parser, struct ArgusModel
                            break;
                         }
                         case k_CiscoV9IcmpTypeV6: {
-                           struct ArgusICMPv6Flow *icmpv6Flow = &flow->canon.flow.icmp6_flow;
+                           struct ArgusICMPv6Flow *icmpv6Flow = &flow->canon.flow.icmpv6_flow;
                            icmpv6Flow->type = value.val8[0];
                            flow->dsrindex |= 1 << ARGUS_FLOW_INDEX;
                            flow->dsrs[ARGUS_FLOW_INDEX] = &flow->canon.flow.hdr;
                            break;
                         }
                         case k_CiscoV9IcmpCodeV6: {
-                           struct ArgusICMPv6Flow *icmpv6Flow = &flow->canon.flow.icmp6_flow;
+                           struct ArgusICMPv6Flow *icmpv6Flow = &flow->canon.flow.icmpv6_flow;
                            icmpv6Flow->code = value.val8[0];
                            flow->dsrindex |= 1 << ARGUS_FLOW_INDEX;
                            flow->dsrs[ARGUS_FLOW_INDEX] = &flow->canon.flow.hdr;
