@@ -520,6 +520,12 @@ ArgusOutputProcess(void *arg)
    sigfillset(&blocked_signals);
    pthread_sigmask(SIG_BLOCK, &blocked_signals, NULL);
 
+#if defined(HAVE_SOLARIS)
+   sigignore(SIGPIPE);
+#else
+   (void) signal (SIGPIPE, SIG_IGN);
+#endif
+
    while ((list = output->ArgusInputList) == NULL) {
       struct timespec tsbuf = {0, 10000000}, *ts = &tsbuf;
 #ifdef ARGUSDEBUG
@@ -870,7 +876,7 @@ ArgusEstablishListen (struct ArgusOutputStruct *output, char *errbuf)
    char *baddr = NULL;
    int s = -1;
 
-   if (port) {
+   if (port > 0) {
       if (output->ArgusListens > 0) {
          int i = output->ArgusListens;
          for (i = 0; i < output->ArgusListens; i++) {
