@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Output include file
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /*
- * $Id: //depot/argus/argus/argus/ArgusOutput.h#16 $
- * $DateTime: 2012/01/03 19:15:19 $
- * $Change: 2274 $
+ * $Id: //depot/argus/argus/argus/ArgusOutput.h#23 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 
@@ -30,8 +30,10 @@
 #ifndef ArgusOutput_h
 #define ArgusOutput_h
 
-#define ARGUS_MONITORPORT	561
-#define ARGUS_MAXLISTEN		16
+#define ARGUS_MONITORPORT		561
+#define ARGUS_MAXLISTEN			10
+
+#define ARGUS_CLIENT_STARTUP_TIMEOUT    5
 
 #include <unistd.h>
 #if defined(HAVE_STDLIB_H)
@@ -74,9 +76,10 @@ struct ArgusClientData {
    struct ArgusQueueHeader qhdr;
    int fd, type, ArgusClientStart;
    int ArgusFilterInitialized;
+   struct timeval startime, lasttime;
    struct ArgusSocketStruct *sock;
    struct nff_program ArgusNFFcode;
-   char *filename, *filter;
+   char *filename, *hostname, *filter;
 
 #if defined(HAVE_GETADDRINFO)
    struct addrinfo *host;
@@ -100,8 +103,6 @@ struct ArgusBindAddrStruct {
 
 
 
-#define ARGUS_MAX_LISTEN	5
-
 struct ArgusOutputStruct {
    struct ArgusSourceStruct *ArgusSrc;
    struct ArgusModelerStruct *ArgusModel;
@@ -131,7 +132,7 @@ struct ArgusOutputStruct {
 #endif
 
    int ArgusPortNum;
-   int ArgusLfd[ARGUS_MAX_LISTEN];
+   int ArgusLfd[ARGUS_MAXLISTEN];
    int ArgusListens, nflag;
  
    char *ArgusBindPort;
@@ -175,7 +176,7 @@ void ArgusInitClientProcess(struct ArgusClientData *, struct ArgusWfileStruct *)
 
 #if defined(ARGUS_TILERA)
 #else
-extern int ArgusFilterCompile(struct nff_program *, char *, int);
+extern char *ArgusFilterCompile(struct nff_program *, char *, int);
 extern unsigned int argus_filter (struct bpf_insn *, unsigned char *);
 #endif
 extern int getArgusPortNum(void);
