@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Input includes
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /*
- * $Id: //depot/argus/argus/argus/ArgusSource.h#38 $
- * $DateTime: 2012/02/28 16:45:56 $
- * $Change: 2317 $
+ * $Id: //depot/argus/argus/argus/ArgusSource.h#47 $
+ * $DateTime: 2015/04/13 00:43:29 $
+ * $Change: 2982 $
  */
 
 /*  ArgusSource.h */
@@ -256,6 +256,7 @@ struct ArgusInterfaceStruct {
    unsigned int ArgusLocalNet, ArgusNetMask;
    struct pcap_stat ArgusStat;
 
+   long ArgusPacketOffset;
    long long ArgusTotalPkts;
    long long ArgusTotalIPPkts;
    long long ArgusTotalNonIPPkts;
@@ -702,7 +703,7 @@ struct ArgusSourceStruct {
    char *ArgusInputFilter;
 
    struct ArgusAddrStruct ArgusID;
-   int type, mode;
+   int ArgusPcapBufSize, type, mode;
 
    struct timeval ArgusStartTime, ArgusEndTime, marktime, lasttime;
 
@@ -737,11 +738,12 @@ struct ArgusSourceStruct {
    int ArgusInputPacketFileType;
    int ArgusReadingOffLine;
    int Argusbpflag, ArgusCaptureFlag;
+   int Argusfflag, ArgusDumpPacket;
    int ArgusDumpPacketOnError;
-   int ArgusDumpPacket;
    unsigned long ArgusPacketOffset;
   
    FILE *ArgusPacketInput;
+   long ArgusInputOffset;
  
    int ArgusSnapLen, ArgusOflag, Arguspflag;
    char **ArgusArgv;
@@ -780,6 +782,7 @@ void Argus802_11RadioAvsPacket (u_char *user, const struct pcap_pkthdr *h, const
 void ArgusEncPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusDagPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusJuniperPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
+void ArgusIpNetPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusNullPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 
 
@@ -888,6 +891,9 @@ static struct callback ArgusSourceCallbacks[] = {
 #endif
 #ifdef DLT_JUNIPER_ETHER
    { ArgusJuniperPacket,   DLT_JUNIPER_ETHER,  "ArgusJuniperPacket()" },
+#endif
+#ifdef DLT_IPNET
+   { ArgusIpNetPacket,   DLT_IPNET,  "ArgusIpNetPacket()" },
 #endif
    { NULL, DLT_NULL, "" },
 #endif
@@ -902,6 +908,7 @@ struct ArgusSourceStruct *ArgusNewSource(struct ArgusModelerStruct *);
 struct ArgusSourceStruct *ArgusCloneSource(struct ArgusSourceStruct *);
 int ArgusInitSource(struct ArgusSourceStruct *);
 int ArgusCloseSource(struct ArgusSourceStruct *);
+void ArgusDeleteSource(struct ArgusSourceStruct *);
 
 extern char *ArgusCopyArgv (char **argv);
 
@@ -916,10 +923,12 @@ int getArgusSnapLen(struct ArgusSourceStruct *);
 void setArgusSnapLen(struct ArgusSourceStruct *, int);
 
 int getArgusbpflag(struct ArgusSourceStruct *);
+int getArgusfflag(struct ArgusSourceStruct *);
 int getArguspflag(struct ArgusSourceStruct *);
 int getArgusOflag(struct ArgusSourceStruct *);
 
 void setArgusbpflag(struct ArgusSourceStruct *, int);
+void setArgusfflag(struct ArgusSourceStruct *, int);
 void setArguspflag(struct ArgusSourceStruct *, int);
 void setArgusOflag(struct ArgusSourceStruct *, int);
 void setArgusCaptureFlag(struct ArgusSourceStruct *, int);
@@ -955,6 +964,7 @@ extern struct ArgusSourceStruct *ArgusNewSource(struct ArgusModelerStruct *);
 extern struct ArgusSourceStruct *ArgusCloneSource(struct ArgusSourceStruct *);
 extern int ArgusInitSource(struct ArgusSourceStruct *);
 extern int ArgusCloseSource(struct ArgusSourceStruct *);
+extern void ArgusDeleteSource(struct ArgusSourceStruct *);
 
 extern struct ArgusOutputStruct *getArgusOutputTask(struct ArgusSourceStruct *);
 extern void setArgusOutputTask(struct ArgusSourceStruct *);
@@ -966,11 +976,13 @@ extern int getArgusSnapLen(struct ArgusSourceStruct *);
 extern void setArgusSnapLen(struct ArgusSourceStruct *, int);
 
 extern int getArgusbpflag(struct ArgusSourceStruct *);
+extern int getArgusfflag(struct ArgusSourceStruct *);
 extern int getArguspflag(struct ArgusSourceStruct *);
 extern int getArgusOflag(struct ArgusSourceStruct *);
 extern int getArgusMoatTshFile (struct ArgusSourceStruct *);
 
 extern void setArgusbpflag(struct ArgusSourceStruct *, int);
+extern void setArgusfflag(struct ArgusSourceStruct *, int);
 extern void setArguspflag(struct ArgusSourceStruct *, int);
 extern void setArgusOflag(struct ArgusSourceStruct *, int);
 extern void setArgusCaptureFlag(struct ArgusSourceStruct *, int);
