@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusTcp.c#50 $
- * $DateTime: 2015/04/14 18:22:14 $
- * $Change: 3006 $
+ * $Id: //depot/argus/argus/argus/ArgusTcp.c#51 $
+ * $DateTime: 2015/07/02 10:42:46 $
+ * $Change: 3030 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -274,35 +274,34 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                   }
                }
 
-               ArgusUpdateTCPSequence(model, flowstr, tcp);
-   
-               switch (ArgusUpdateTCPStateMachine(model, flowstr, tcp)) {
-                  case TCPS_LISTEN:
-                     if (flags == TH_SYN) {
-                        ArgusThisTCPsrc->bytes -= model->ArgusThisLength;
-                        model->ArgusThisUpHdr  -= tcphlen;
-                        model->ArgusThisLength = tcplen;
-                        model->ArgusSnapLength += tcphlen;
+               if (ArgusUpdateTCPSequence(model, flowstr, tcp)) {
+                  switch (ArgusUpdateTCPStateMachine(model, flowstr, tcp)) {
+                     case TCPS_LISTEN:
+                        if (flags == TH_SYN) {
+                           ArgusThisTCPsrc->bytes -= model->ArgusThisLength;
+                           model->ArgusThisUpHdr  -= tcphlen;
+                           model->ArgusThisLength = tcplen;
+                           model->ArgusSnapLength += tcphlen;
 
-                        ArgusRemoveFromQueue (flowstr->qhdr.queue, &flowstr->qhdr, ARGUS_LOCK);
-                        ArgusSendFlowRecord (model, flowstr, ARGUS_STOP);
-                        ArgusInitializeTCP (model, flowstr);
-                        ArgusPushQueue(model->ArgusStatusQueue, &flowstr->qhdr, ARGUS_LOCK);
-                        return;
-                     }
-                     break;
+                           ArgusRemoveFromQueue (flowstr->qhdr.queue, &flowstr->qhdr, ARGUS_LOCK);
+                           ArgusSendFlowRecord (model, flowstr, ARGUS_STOP);
+                           ArgusInitializeTCP (model, flowstr);
+                           ArgusPushQueue(model->ArgusStatusQueue, &flowstr->qhdr, ARGUS_LOCK);
+                           return;
+                        }
+                        break;
    
-                  case TCPS_CLOSED:
-                  case TCPS_TIME_WAIT:
-                     if (!(tcpExt->status & ARGUS_RESET))
-                        tcpExt->status |= ARGUS_NORMAL_CLOSE;
-                     flowstr->timeout = 10;
-                     break;
+                     case TCPS_CLOSED:
+                     case TCPS_TIME_WAIT:
+                        if (!(tcpExt->status & ARGUS_RESET))
+                           tcpExt->status |= ARGUS_NORMAL_CLOSE;
+                        flowstr->timeout = 10;
+                        break;
+                  }
                }
-   
-               ArgusThisTCPsrc->lasttime.tv_sec  = model->ArgusGlobalTime.tv_sec;
-               ArgusThisTCPsrc->lasttime.tv_usec = model->ArgusGlobalTime.tv_usec;
             }
+            ArgusThisTCPsrc->lasttime.tv_sec  = model->ArgusGlobalTime.tv_sec;
+            ArgusThisTCPsrc->lasttime.tv_usec = model->ArgusGlobalTime.tv_usec;
          }
       }
    }
@@ -523,7 +522,7 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
    unsigned char flags = tcp->th_flags;
    int len = model->ArgusThisLength;
 
-   int retn = 1, win;
+   int retn = 1, win, ArgusDuplicatePacket = 0;
    unsigned int maxseq = 0;
    unsigned int seq = tcp->th_seq;
    unsigned int newseq = seq + len;
@@ -595,14 +594,15 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
          ArgusThisTCPsrc->seqbase = seq;
          ArgusThisTCPsrc->seq = newseq;
       } else {
+
          if (len) {
             if (model->ArgusTrackDuplicates && (tipid && ((ipid != 0) && (*tipid == ipid)))) {
-/*
                if (model->ArgusThisDir) 
-                  tcpExt->sdups++;
+                  ArgusThisTCPsrc->status |= ARGUS_SRC_DUPLICATES;
                else
-                  tcpExt->ddups++;
-*/
+                  ArgusThisTCPdst->status |= ARGUS_DST_DUPLICATES;
+               ArgusDuplicatePacket = 1;
+
             } else {
                if (ArgusThisTCPdst->win != 0) {           /* not first packet seen in this direction */
                   if (tcp->th_seq < ArgusThisTCPdst->ack) {
@@ -657,34 +657,37 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
    }
 
 
-   if (tcp->th_ack && (flags & TH_ACK)) {
-      if (ArgusThisTCPsrc->ack) {
-         if (ArgusThisTCPdst->seq > ArgusThisTCPsrc->ack)
-            ArgusThisTCPdst->winbytes = (ArgusThisTCPdst->seq - 1) - ArgusThisTCPsrc->ack;  
-      }
-
-      if (!(ArgusThisTCPsrc->ack == (tcp->th_ack - 1))) {
-         if (!(ArgusThisTCPsrc->ack) || (ArgusThisTCPdst->seq == tcp->th_ack)) {
-
-            ArgusThisTCPdst->winbytes = 0;
-            if (!(ArgusThisTCPsrc->ack == (tcp->th_ack - 1)))
-               if (ArgusThisTCPdst->seq == tcp->th_ack)
-                  ArgusThisTCPdst->winnum++;
-
-         } else {
-            if (!(flags & TH_SYN))
-               if (ArgusThisTCPsrc->ack) {
-                  win = (tcp->th_ack - 1) - ArgusThisTCPsrc->ack;
-                  win = (ArgusThisTCPdst->winbytes < win) ? ArgusThisTCPdst->winbytes : win;
-                  ArgusThisTCPdst->winbytes -= win;
-                  ArgusThisTCPdst->winnum++;
-               }
+   if (!(ArgusDuplicatePacket)) {
+      if (tcp->th_ack && (flags & TH_ACK)) {
+         if (ArgusThisTCPsrc->ack) {
+            if (ArgusThisTCPdst->seq > ArgusThisTCPsrc->ack)
+               ArgusThisTCPdst->winbytes = (ArgusThisTCPdst->seq - 1) - ArgusThisTCPsrc->ack;  
          }
 
-         ArgusThisTCPsrc->ack = tcp->th_ack - 1;
-      }
-   }
+         if (!(ArgusThisTCPsrc->ack == (tcp->th_ack - 1))) {
+            if (!(ArgusThisTCPsrc->ack) || (ArgusThisTCPdst->seq == tcp->th_ack)) {
 
+               ArgusThisTCPdst->winbytes = 0;
+               if (!(ArgusThisTCPsrc->ack == (tcp->th_ack - 1)))
+                  if (ArgusThisTCPdst->seq == tcp->th_ack)
+                     ArgusThisTCPdst->winnum++;
+
+            } else {
+               if (!(flags & TH_SYN))
+                  if (ArgusThisTCPsrc->ack) {
+                     win = (tcp->th_ack - 1) - ArgusThisTCPsrc->ack;
+                     win = (ArgusThisTCPdst->winbytes < win) ? ArgusThisTCPdst->winbytes : win;
+                     ArgusThisTCPdst->winbytes -= win;
+                     ArgusThisTCPdst->winnum++;
+                  }
+            }
+
+            ArgusThisTCPsrc->ack = tcp->th_ack - 1;
+         }
+      }
+
+   } else
+      retn = 0;
 
 /* ArgusInProtocol = 1; */
 
@@ -939,30 +942,33 @@ ArgusTCPFlowRecord (struct ArgusNetworkStruct *net, unsigned char state)
 
    net->hdr.argus_dsrvl8.qual = 0;
 
-   tcp->status &= ~ARGUS_RESET;
+   tcp->status &= ~(ARGUS_RESET | ARGUS_PKTS_RETRANS | ARGUS_WINDOW_SHUT | ARGUS_OUTOFORDER | ARGUS_DUPLICATES);
+
    if (tcp->src.status & ARGUS_RESET)
       tcp->status |= ARGUS_SRC_RESET;
    if (tcp->dst.status & ARGUS_RESET)
       tcp->status |= ARGUS_DST_RESET;
 
-   tcp->status &= ~ARGUS_PKTS_RETRANS;
    if (tcp->src.status & ARGUS_PKTS_RETRANS)
       tcp->status |= ARGUS_SRC_PKTS_RETRANS;
    if (tcp->dst.status & ARGUS_PKTS_RETRANS)
       tcp->status |= ARGUS_DST_PKTS_RETRANS;
 
-   tcp->status &= ~ARGUS_WINDOW_SHUT;
    if (tcp->src.status & ARGUS_WINDOW_SHUT)
       tcp->status |= ARGUS_SRC_WINDOW_SHUT;
    if (tcp->dst.status & ARGUS_WINDOW_SHUT)
       tcp->status |= ARGUS_DST_WINDOW_SHUT;
 
-   tcp->status &= ~ARGUS_OUTOFORDER;
    if (tcp->src.status & ARGUS_OUTOFORDER)
       tcp->status |= ARGUS_SRC_OUTOFORDER;
    if (tcp->dst.status & ARGUS_OUTOFORDER)
       tcp->status |= ARGUS_DST_OUTOFORDER;
 
+   if (tcp->src.status & ARGUS_DUPLICATES)
+      tcp->status |= ARGUS_SRC_DUPLICATES;
+   if (tcp->dst.status & ARGUS_DUPLICATES)
+      tcp->status |= ARGUS_DST_DUPLICATES;
+
    switch (net->hdr.subtype) {
       case ARGUS_TCP_INIT:
          net->hdr.argus_dsrvl8.len  = ((sizeof(struct ArgusTCPInitStatus)+3))/4 + 1;
