@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusUdt.c#9 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/argus/ArgusUdt.c#10 $
+ * $DateTime: 2015/06/29 16:17:25 $
+ * $Change: 3027 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -176,9 +176,6 @@ ArgusUpdateUDToEState (struct ArgusModelerStruct *model, struct ArgusFlowStruct
                         hshake->wsize = ntohl(hshake->wsize);
                         hshake->conntype = ntohl(hshake->conntype);
                         hshake->sockid = ntohl(hshake->sockid);
-
-                     } else {
-//                      ArgusLog(LOG_ERR, "ArgusUpdateUDToEState: hshake version is %d", ntohl(hshake->version));
                      }
 #ifdef ARGUSDEBUG
                      ArgusDebug (4, "ArgusUpdateUDToEState(%p, %d) UDT_CONTROL_HANDSHAKE type %d seqNum %d size %d maxWin %d conn %d sockid 0x%x\n", 
@@ -285,7 +282,8 @@ ArgusUpdateUDToEState (struct ArgusModelerStruct *model, struct ArgusFlowStruct
                   case UDTOE_CONTROL_DROPREQ: {
                      struct udt_control_dropreq *drop = (void *)(udtc + 1);
                      if (drop->firstseqnum == 0)
-                        ArgusLog(LOG_ERR, "drop request firstseqnum is 0");
+                        if (net != NULL)
+                           net->net_union.udt.status |= ARGUS_UDT_FIRSTDROPZERO;
 #ifdef ARGUSDEBUG
                      ArgusDebug (4, "ArgusUpdateUDToEState(%p, %d) UDT_CONTROL_DROPREQ\n", flowstr, *state);
 #endif
@@ -534,7 +532,8 @@ ArgusUpdateUDTState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                   case UDT_CONTROL_DROPREQ: {
                      struct udt_control_dropreq *drop = (void *)(udtc + 1);
                      if (drop->firstseqnum == 0)
-                        ArgusLog(LOG_ERR, "drop request firstseqnum is 0");
+                        if (net != NULL)
+                           net->net_union.udt.status |= ARGUS_UDT_FIRSTDROPZERO;
 #ifdef ARGUSDEBUG
                      ArgusDebug (4, "ArgusUpdateUDTState(%p, %d) UDT_CONTROL_DROPREQ\n", flowstr, *state);
 #endif
@@ -648,10 +647,10 @@ ArgusUDTFlowRecord (struct ArgusFlowStruct *flow, struct ArgusRecord *argus, uns
 
 
 struct udt_control_handshake *ArgusThisUdtHshake = NULL;
-int ArgusParseUDToEHeader (struct ArgusModelerStruct *, struct udt_header *);
+int ArgusParseUDToEHeader (struct ArgusModelerStruct *, struct udt_header *, unsigned int *);
 
 int
-ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
+ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt, unsigned int *status)
 {
    int retn = 0;
 
@@ -667,8 +666,8 @@ ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
                   if (ntohl(hshake->version) == 4) {
                      ArgusThisUdtHshake = hshake;
                      retn = 1;
-                  } else 
-//                   ArgusLog(LOG_ERR, "ArgusParseUDToEHeader: hshake version is %d", ntohl(hshake->version));
+                  } else
+                     *status |= ARGUS_UDT_BADVERSION;
                   break;
                }
                case UDTOE_CONTROL_KEEPALIVE:
@@ -676,9 +675,6 @@ ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
                   break;
 
                case UDTOE_CONTROL_ACK: {
-/*
-                  struct udt_control_ack *ack = (void *) (udtc + 1);
-*/
                   retn = 1;
                   break;
                }
@@ -695,7 +691,7 @@ ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
                case UDTOE_CONTROL_DROPREQ: {
                   struct udt_control_dropreq *drop = (void *)(udtc + 1);
                   if (drop->firstseqnum == 0)
-                     ArgusLog(LOG_ERR, "drop request firstseqnum is 0");
+                     *status |= ARGUS_UDT_FIRSTDROPZERO;
                   retn = 1;
                   break;
                }
@@ -713,7 +709,7 @@ ArgusParseUDToEHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
 
 
 int
-ArgusParseUDTHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
+ArgusParseUDTHeader (struct ArgusModelerStruct *model, struct udt_header *udt, unsigned int *status)
 {
    int retn = 0;
 
@@ -730,7 +726,7 @@ ArgusParseUDTHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
                      ArgusThisUdtHshake = hshake;
                      retn = 1;
                   } else 
-//                   ArgusLog(LOG_ERR, "ArgusParseUDTHeader: hshake version is %d", ntohl(hshake->version));
+                     *status |= ARGUS_UDT_BADVERSION;
                   break;
                }
                case UDT_CONTROL_KEEPALIVE:
@@ -757,7 +753,7 @@ ArgusParseUDTHeader (struct ArgusModelerStruct *model, struct udt_header *udt)
                case UDT_CONTROL_DROPREQ: {
                   struct udt_control_dropreq *drop = (void *)(udt + 1);
                   if (drop->firstseqnum == 0)
-                     ArgusLog(LOG_ERR, "drop request firstseqnum is 0");
+                     *status |= ARGUS_UDT_FIRSTDROPZERO;
                   retn = 1;
                   break;
                }
