@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusUtil.c#87 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/argus/ArgusUtil.c#88 $
+ * $DateTime: 2015/08/06 16:35:55 $
+ * $Change: 3044 $
  */
 
 /* ArgusUtil.c */
@@ -169,9 +169,9 @@ ArgusDeleteList (struct ArgusListStruct *list, int type)
             }
 
              case ARGUS_BIND_ADDR_LIST: {
-                struct ArgusListObjectStruct *lobj = (struct ArgusListObjectStruct *) retn;
-                if (lobj->obj != NULL) {
-                   free(lobj);
+                struct ArgusBindAddrStruct *baddr = (struct ArgusBindAddrStruct *) retn;
+                if (baddr->addr != NULL) {
+                   free(baddr->addr);
                 }
                 ArgusFree(retn);
                 break;
