@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Utilities include files
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,9 +42,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusUtil.h#28 $
- * $DateTime: 2012/01/03 19:15:19 $
- * $Change: 2274 $
+ * $Id: //depot/argus/argus/argus/ArgusUtil.h#33 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 
@@ -216,6 +216,10 @@ extern void ArgusDebug (int, char *, ...);
 
 struct timeval *RaMinTime (struct timeval *, struct timeval *);
 struct timeval *RaMaxTime (struct timeval *, struct timeval *); 
+
+float RaDeltaFloatTime (struct timeval *, struct timeval *);
+
+int RaDiffTime (struct timeval *, struct timeval *, struct timeval *); 
 float RaGetFloatDuration (struct ArgusRecordStruct *); 
 float RaGetFloatSrcDuration (struct ArgusRecordStruct *); 
 float RaGetFloatDstDuration (struct ArgusRecordStruct *);
@@ -234,6 +238,7 @@ double ArgusFetchPercentDstLoss (struct ArgusRecordStruct *);
 double ArgusFetchRate (struct ArgusRecordStruct *);
 double ArgusFetchSrcRate (struct ArgusRecordStruct *);
 double ArgusFetchDstRate (struct ArgusRecordStruct *);
+double ArgusFetchAppByteRatio (struct ArgusRecordStruct *);
 
 #else
 
@@ -298,6 +303,10 @@ extern void ArgusDebug (int, char *, ...);
   
 extern struct timeval *RaMinTime (struct timeval *, struct timeval *);
 extern struct timeval *RaMaxTime (struct timeval *, struct timeval *); 
+
+extern float RaDeltaFloatTime (struct timeval *, struct timeval *);
+
+extern int RaDiffTime (struct timeval *, struct timeval *, struct timeval *); 
 extern float RaGetFloatDuration (struct ArgusRecordStruct *); 
 extern float RaGetFloatSrcDuration (struct ArgusRecordStruct *); 
 extern float RaGetFloatDstDuration (struct ArgusRecordStruct *);
@@ -316,6 +325,7 @@ extern double ArgusFetchPercentDstLoss (struct ArgusRecordStruct *);
 extern double ArgusFetchRate (struct ArgusRecordStruct *);
 extern double ArgusFetchSrcRate (struct ArgusRecordStruct *);
 extern double ArgusFetchDstRate (struct ArgusRecordStruct *);
+extern double ArgusFetchAppByteRatio (struct ArgusRecordStruct *);
 
 #endif
 #endif
