@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/argus.c#100 $
- * $DateTime: 2015/04/13 00:43:29 $
- * $Change: 2982 $
+ * $Id: //depot/argus/argus/argus/argus.c#101 $
+ * $DateTime: 2015/07/02 10:42:46 $
+ * $Change: 3030 $
  */
 
 /*
@@ -1408,12 +1408,12 @@ ArgusParseResourceFile (struct ArgusModelerStruct *model, char *file)
                         }
 
                         case ARGUS_CAPTURE_FULL_CONTROL_DATA:
-                           if ((strncasecmp(optarg, "yes", 3)) != 0) {
-                              setArgusCaptureFlag (ArgusSourceTask, 1);
-                              setArgusSnapLen (ArgusSourceTask, (getArgusUserDataLen(ArgusModel) + ARGUS_MINSNAPLEN));
+                           if (!(strncasecmp(optarg, "yes", 3))) {
+                              setArgusCaptureFlag(ArgusSourceTask, 1);
+                              setArgusControlMonitor(ArgusModel);
+                              setArgusSnapLen(ArgusSourceTask, ARGUS_MAXSNAPLEN);
                            } else {
                               setArgusCaptureFlag (ArgusSourceTask, 0);
-                              setArgusSnapLen (ArgusSourceTask, ARGUS_MAXSNAPLEN);
                            }
                            break;
 
