@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_def.h#47 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/include/argus_def.h#49 $
+ * $DateTime: 2015/07/02 09:02:44 $
+ * $Change: 3029 $
  */
 
 /* Argus_def.h */
@@ -1595,6 +1595,10 @@ extern "C" {
 #define ARGUS_SRC_OUTOFORDER    	0x00010000
 #define ARGUS_DST_OUTOFORDER    	0x00020000
 
+#define ARGUS_DUPLICATES		0x000C0000
+#define ARGUS_SRC_DUPLICATES    	0x00040000
+#define ARGUS_DST_DUPLICATES    	0x00080000
+
 #define ARGUS_TCP_OPTIONS		0xFFF00000
 #define ARGUS_TCP_MAXSEG		0x00100000
 #define ARGUS_TCP_WSCALE		0x00200000
@@ -1609,6 +1613,10 @@ extern "C" {
 #define ARGUS_TCP_SRC_ECN		0x40000000
 #define ARGUS_TCP_DST_ECN		0x80000000
 
+#define ARGUS_UDT_OPTIONS		0xFFF00000
+#define ARGUS_UDT_BADVERSION		0x00100000
+#define ARGUS_UDT_FIRSTDROPZERO		0x01000000
+
 /* ESP State Constatans and Reporting Values */
 #define ARGUS_ESP_ROLLOVER              0x1000
 #define ARGUS_ESP_SEQFAILURE            0x2000
