@@ -41,33 +41,41 @@ struct ArgusEncapsulationStruct {
    char *label, *desc;
 };
 
-#define ARGUS_ENCAPS_TYPE       25
+#define ARGUS_ENCAPS_TYPE       28
+
 #define ARGUS_ENCAPS_MPLS       0x01
 #define ARGUS_ENCAPS_ETHER      0x02
 #define ARGUS_ENCAPS_8021Q      0x04
 #define ARGUS_ENCAPS_LLC        0x08
 #define ARGUS_ENCAPS_PPP        0x10
+
 #define ARGUS_ENCAPS_ISL        0x20
 #define ARGUS_ENCAPS_GRE        0x40
 #define ARGUS_ENCAPS_AH         0x80
 #define ARGUS_ENCAPS_IP         0x100
 #define ARGUS_ENCAPS_IPV6       0x200
+
 #define ARGUS_ENCAPS_HDLC       0x400
 #define ARGUS_ENCAPS_CHDLC      0x800
 #define ARGUS_ENCAPS_ATM        0x1000
 #define ARGUS_ENCAPS_SLL        0x2000
 #define ARGUS_ENCAPS_FDDI       0x4000
+
 #define ARGUS_ENCAPS_SLIP       0x8000
 #define ARGUS_ENCAPS_ARCNET     0x10000
 #define ARGUS_ENCAPS_802_11     0x20000
 #define ARGUS_ENCAPS_PRISM      0x40000
 #define ARGUS_ENCAPS_AVS        0x80000
+
 #define ARGUS_ENCAPS_IB_LRH     0x100000
 #define ARGUS_ENCAPS_IB_GRH     0x200000
 #define ARGUS_ENCAPS_TEREDO     0x400000
 #define ARGUS_ENCAPS_UDT        0x800000
 #define ARGUS_ENCAPS_SPI        0x1000000
+
 #define ARGUS_ENCAPS_JUNIPER    0x2000000
+#define ARGUS_ENCAPS_ERSPAN_II  0x4000000
+
 
 #if defined(ArgusUtil)
 struct ArgusEncapsulationStruct argus_encapsulations [] = {
@@ -96,6 +104,7 @@ struct ArgusEncapsulationStruct argus_encapsulations [] = {
    { ARGUS_ENCAPS_TEREDO,"teredo", "Teredo IPV6 Tunneling"},
    { ARGUS_ENCAPS_SPI,   "enc", "IPsec Tunnel"},
    { ARGUS_ENCAPS_JUNIPER, "juniper", "Juniper Ethernet"},
+   { ARGUS_ENCAPS_ERSPAN_II, "erspan_ii", "Cisco ERSPAN II"},
    { 0, (char *) NULL, (char *) NULL }, 
 };
 
