@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -61,9 +61,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_filter.h#14 $
- * $DateTime: 2012/01/03 19:15:19 $
- * $Change: 2274 $
+ * $Id: //depot/argus/argus/include/argus_filter.h#18 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 
@@ -108,8 +108,8 @@ int ArgusLookupNet(char *, unsigned int *, unsigned int *, char *);
 char *read_infile(char *);
 
 static inline int xdtoi(int c);
-unsigned int ArgusFilterRecord (struct nff_insn *pc,  struct ArgusRecordStruct *);
-unsigned int ArgusFilterOrig (struct nff_insn *, struct ArgusRecordStruct *, int, int);
+int ArgusFilterRecord (struct nff_insn *pc,  struct ArgusRecordStruct *);
+int ArgusFilterOrig (struct nff_insn *, struct ArgusRecordStruct *, int, int);
 
 static inline int skip_space(FILE *);
 static inline int skip_line(FILE *);
@@ -155,6 +155,7 @@ unsigned int getnetnumber(unsigned int);
 
 void nff_dump(struct nff_program *, char *, int, int);
 
+
 char *intoa(unsigned int);
 extern SIGRET nohostname(int);
 char *ArgusGetName(struct ArgusParserStruct *, unsigned char *);
@@ -198,8 +199,8 @@ extern void ArgusPrintHex (const unsigned char *, unsigned int);
 extern int ArgusLookupNet(char *, unsigned int *, unsigned int *, char *);
 extern char *read_infile(char *);
 
-extern unsigned int ArgusFilterRecord (struct nff_insn *pc,  struct ArgusRecordStruct *);
-extern unsigned int ArgusFilterOrig (struct nff_insn *, u_char *, int, int);
+extern int ArgusFilterRecord (struct nff_insn *pc,  struct ArgusRecordStruct *);
+extern int ArgusFilterOrig (struct nff_insn *, u_char *, int, int);
 
 //extern struct argus_etherent *argus_next_etherent(FILE *fp);
 extern char *ArgusLookupDev(char *);
