@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_out.h#52 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/argus/argus/include/argus_out.h#53 $
+ * $DateTime: 2015/08/05 22:33:18 $
+ * $Change: 3042 $
  */
 
 
@@ -527,7 +527,7 @@ struct ArgusSystemFlow {
 
 #define    ipv6_flow flow_un.ipv6
 #define      ip_flow flow_un.ip
-#define   icmp6_flow flow_un.icmpv6
+#define  icmpv6_flow flow_un.icmpv6
 #define    icmp_flow flow_un.icmp
 #define    igmp_flow flow_un.igmp
 #define   igmp6_flow flow_un.igmpv6
