@@ -1,6 +1,6 @@
 /*
  * Argus Software Common include files - Parser
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_parser.h#15 $
- * $DateTime: 2012/03/15 01:13:08 $
- * $Change: 2335 $
+ * $Id: //depot/argus/argus/include/argus_parser.h#21 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 
@@ -41,7 +41,6 @@
 
 #include <argus_debug.h>
 #include <argus_def.h>
-#include <argus_out.h>
 #include <argus_int.h>
 
 #define ARGUS_PRINTSRC	0x0001
@@ -61,6 +60,18 @@
 #define ARGUS_MAX_S_OPTIONS      34 
 #define HASHNAMESIZE		256
 
+#define ARGUS_FORCE_LOCAL_SRC           0x02
+#define ARGUS_FORCE_LOCAL_DST           0x04
+#define ARGUS_SUGGEST_LOCAL_SRC         0x08
+#define ARGUS_SUGGEST_LOCAL_DST         0x10
+
+#define ARGUS_PORT_SERVICES             0x100
+#define ARGUS_PORT_WELLKNOWN            0x200
+#define ARGUS_PORT_REGISTERED           0x400
+
+#define ARGUS_ADDR_DIR_MASK (ARGUS_SUGGEST_LOCAL_SRC | ARGUS_SUGGEST_LOCAL_DST | ARGUS_FORCE_LOCAL_SRC | ARGUS_FORCE_LOCAL_DST)
+#define ARGUS_PORT_DIR_MASK (ARGUS_PORT_SERVICES | ARGUS_PORT_WELLKNOWN | ARGUS_PORT_REGISTERED)
+
 #include <netinet/in.h>
  
 struct h6namemem {
@@ -102,13 +113,14 @@ struct ArgusParserStruct {
    int status;
    char fflag, nflag, tflag, uflag, Wflag;
    char Iflag, Tflag, rflag, Rflag, Sflag, xflag;
-   char Xflag, XMLflag, zflag, Zflag;
+   char Xflag, XMLflag, zflag, Zflag, pflag;
 
    int RaCumulativeMerge, RaFlowMajorModified;
    int RaAllocHashTableHealers, RaAllocArgusRecord;
    int RaThisActiveIndex, RaThisFlowNum;
    int RaThisModelNum, RaParseError;
    int ArgusSessionId, NonBlockingDNS, ArgusDSCodePoints;
+   int ArgusDirectionFunction;
 
    char *RaFlowModelFile, *ArgusFlowModelFile, *ArgusRemoteFilter;
    struct RaFlowModelStruct *RaFlowModel;
@@ -120,6 +132,8 @@ struct ArgusParserStruct {
 
    int ArgusFilterFiledes[2];
    int ArgusControlFiledes[2];
+
+   int ArgusSrvInit;
  
    unsigned int f_localnet, f_netmask;
    struct protoidmem protoidtable[HASHNAMESIZE];
