@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Common include files - Utilities
- * Copyright (c) 2000-201! QoSient, LLC
+ * Copyright (c) 2000-2015 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_util.h#17 $
- * $DateTime: 2012/04/13 11:28:33 $
- * $Change: 2361 $
+ * $Id: //depot/argus/argus/include/argus_util.h#24 $
+ * $DateTime: 2015/04/06 10:38:44 $
+ * $Change: 2973 $
  */
 
 #if !defined(Argus_util_h)
@@ -34,7 +34,9 @@
 #endif
 #include <netinet/ip.h>
 
+#include <argus_parser.h>
 #include <argus_def.h>
+
 #include <argus/cons_out.h>
 
 #include <argus/CflowdFlowPdu.h>
@@ -156,6 +158,8 @@ void *ArgusMallocListRecord (int length);
 
 void ArgusLog (int, char *, ...);
 
+void ArgusInitServarray(struct ArgusParserStruct *);
+
 #else
 
 extern void ArgusAdjustGlobalTime (struct timeval *);
